@@ -56,6 +56,14 @@ class MembraneQuad6:
         self.eta = eta
         self.w = w
 
+    def get_coordinates(self) -> tuple[np.ndarray, np.ndarray]:
+        """
+        Retorna las coordenadas de los nodos del elemento.
+        """
+        x = np.array([self.node1.vertex.x, self.node2.vertex.x, self.node3.vertex.x, self.node4.vertex.x])
+        y = np.array([self.node1.vertex.y, self.node2.vertex.y, self.node3.vertex.y, self.node4.vertex.y])
+        return x, y
+
     def shape_function(self, xi: float, eta: float):
         """
         Funciones de forma.
