@@ -55,6 +55,15 @@ class MembraneQuad4:
         N4 = 1/4 * (1-xi) * (1+eta)
         return N1, N2, N3, N4
 
+    def get_coordinates(self) -> tuple[np.ndarray, np.ndarray]:
+        """
+        Retorna las coordenadas de los nodos del elemento.
+        """
+        x = np.array([self.node1.vertex.x, self.node2.vertex.x, self.node3.vertex.x, self.node4.vertex.x])
+        y = np.array([self.node1.vertex.y, self.node2.vertex.y, self.node3.vertex.y, self.node4.vertex.y])
+        return x, y
+
+
     def coordinates(self, xi: float, eta: float) -> tuple[float, float]:
         """
         Calcula las coordenadas en un punto (xi, eta).
